==> zio-aws-sagemakerruntime_3-5.17.197.1-sources.jar: zio/aws/sagemakerruntime/model/package.scala <==
package zio.aws.sagemakerruntime
import zio.prelude.Subtype
import zio.Chunk
import zio.aws.sagemakerruntime.model.primitives.InputLocationHeader.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object BodyBlob extends Subtype[Chunk[Byte]]
    type BodyBlob = zio.aws.sagemakerruntime.model.primitives.BodyBlob.Type
    object CustomAttributesHeader extends Subtype[String]
    type CustomAttributesHeader =
      zio.aws.sagemakerruntime.model.primitives.CustomAttributesHeader.Type
    object EndpointName extends Subtype[String]
    type EndpointName =
      zio.aws.sagemakerruntime.model.primitives.EndpointName.Type
    object Header extends Subtype[String]
    type Header = zio.aws.sagemakerruntime.model.primitives.Header.Type
    object InferenceId extends Subtype[String]
    type InferenceId =
      zio.aws.sagemakerruntime.model.primitives.InferenceId.Type
    object InputLocationHeader extends Subtype[String]
    type InputLocationHeader =
      zio.aws.sagemakerruntime.model.primitives.InputLocationHeader.Type
    object RequestTTLSecondsHeader extends Subtype[Int]
    type RequestTTLSecondsHeader =
      zio.aws.sagemakerruntime.model.primitives.RequestTTLSecondsHeader.Type
    object TargetContainerHostnameHeader extends Subtype[String]
    type TargetContainerHostnameHeader =
      zio.aws.sagemakerruntime.model.primitives.TargetContainerHostnameHeader.Type
    object TargetModelHeader extends Subtype[String]
    type TargetModelHeader =
      zio.aws.sagemakerruntime.model.primitives.TargetModelHeader.Type
    object TargetVariantHeader extends Subtype[String]
    type TargetVariantHeader =
      zio.aws.sagemakerruntime.model.primitives.TargetVariantHeader.Type
  }
}

==> zio-aws-sagemakerruntime_3-5.17.295.10-sources.jar: zio/aws/sagemakerruntime/model/package.scala <==
package zio.aws.sagemakerruntime
import zio.prelude.Subtype
import zio.Chunk
import zio.aws.sagemakerruntime.model.primitives.InputLocationHeader.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object BodyBlob extends Subtype[Chunk[Byte]]
    type BodyBlob = zio.aws.sagemakerruntime.model.primitives.BodyBlob.Type
    object CustomAttributesHeader extends Subtype[String]
    type CustomAttributesHeader =
      zio.aws.sagemakerruntime.model.primitives.CustomAttributesHeader.Type
    object EnableExplanationsHeader extends Subtype[String]
    type EnableExplanationsHeader =
      zio.aws.sagemakerruntime.model.primitives.EnableExplanationsHeader.Type
    object EndpointName extends Subtype[String]
    type EndpointName =
      zio.aws.sagemakerruntime.model.primitives.EndpointName.Type
    object Header extends Subtype[String]
    type Header = zio.aws.sagemakerruntime.model.primitives.Header.Type
    object InferenceId extends Subtype[String]
    type InferenceId =
      zio.aws.sagemakerruntime.model.primitives.InferenceId.Type
    object InputLocationHeader extends Subtype[String]
    type InputLocationHeader =
      zio.aws.sagemakerruntime.model.primitives.InputLocationHeader.Type
    object RequestTTLSecondsHeader extends Subtype[Int]
    type RequestTTLSecondsHeader =
      zio.aws.sagemakerruntime.model.primitives.RequestTTLSecondsHeader.Type
    object TargetContainerHostnameHeader extends Subtype[String]
    type TargetContainerHostnameHeader =
      zio.aws.sagemakerruntime.model.primitives.TargetContainerHostnameHeader.Type
    object TargetModelHeader extends Subtype[String]
    type TargetModelHeader =
      zio.aws.sagemakerruntime.model.primitives.TargetModelHeader.Type
    object TargetVariantHeader extends Subtype[String]
    type TargetVariantHeader =
      zio.aws.sagemakerruntime.model.primitives.TargetVariantHeader.Type
  }
}
